@@ -14,12 +14,6 @@ PRODUCT_MODEL = MODELS.get('PRODUCT', PRODUCT_MODEL_DEFAULT)
 CATEGORY_MODEL_DEFAULT = 'plugshop.models.category.Category'
 CATEGORY_MODEL = MODELS.get('CATEGORY', CATEGORY_MODEL_DEFAULT)
 
-SHIPPING_MODEL_DEFAULT =  'plugshop.models.shipping.Shipping'
-SHIPPING_MODEL = MODELS.get('SHIPPING', SHIPPING_MODEL_DEFAULT)
-
-SHIPPING_TYPE_MODEL_DEFAULT = 'plugshop.models.shipping_type.ShippingType'
-SHIPPING_TYPE_MODEL = MODELS.get('SHIPPING_TYPE', SHIPPING_TYPE_MODEL_DEFAULT)
-
 ORDER_MODEL_DEFAULT = 'plugshop.models.order.Order'
 ORDER_MODEL = MODELS.get('ORDER', ORDER_MODEL_DEFAULT)
                 
